.. _reference:


API reference
=============

.. currentmodule:: clustergram.clustergram

.. autoclass:: Clustergram
   :members: fit, plot, from_data, from_centers, silhouette_score, calinski_harabasz_score, davies_bouldin_score, bokeh